@@ -26,7 +26,6 @@ from __future__ import absolute_import, print_function
 
 import apt
 import apt_pkg
-import datetime
 import dbus
 from gettext import gettext as _
 import gettext
@@ -40,6 +39,7 @@ import sys
 
 import gi
 gi.require_version("Gdk", "3.0")
+gi.require_version("Gtk", "3.0")
 from gi.repository import GObject, Gdk, Gtk, Gio, GLib
 
 from .SimpleGtkbuilderApp import SimpleGtkbuilderApp
@@ -48,20 +48,12 @@ from .DialogMirror import DialogMirror
 from .DialogEdit import DialogEdit
 from .DialogCacheOutdated import DialogCacheOutdated
 from .DialogAddSourcesList import DialogAddSourcesList
-from .UbuntuProPage import UbuntuProPage
 
 import softwareproperties
 import softwareproperties.distro
 from softwareproperties.SoftwareProperties import SoftwareProperties
 import softwareproperties.SoftwareProperties
 
-from softwareproperties.gtk.utils import (
-    get_ua_status,
-    get_ua_service_status,
-    current_distro,
-    is_current_distro_lts,
-)
-
 from UbuntuDrivers import detect
 
 if GLib.pyglib_version < (3, 9, 1):
@@ -190,8 +182,6 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         self.show_distro()
         # Setup and show the Additonal Drivers tab
         self.init_drivers()
-        # Setup and show the Ubuntu Pro tab
-        self.init_ubuntu_pro()
 
         # Connect to switch-page before setting initial tab. Otherwise the
         # first switch goes unnoticed.
@@ -362,57 +352,6 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
                 self.vbox_updates.add(checkbox)
             checkbox.show()
 
-        status = get_ua_status()
-        if not is_current_distro_lts():
-                esm_available = False
-                esm_enabled = False
-        else:
-                (infra_available, infra_status) = get_ua_service_status("esm-infra", status=status)
-                (apps_available, apps_status) = get_ua_service_status("esm-apps", status=status)
-                esm_available = bool(infra_available or apps_available)
-                esm_enabled = "enabled" in (infra_status, apps_status)
-        distro = current_distro()
-        if esm_enabled:
-                eol_text = _("Extended Security Maintenance")
-                # EOL date should probably be UA contract expiry.
-                # This is probably sooner than ESM EOL for the distro and
-                # gives software properties dialogs a chance to interact about
-                # renewals if needed.
-                try:
-                        # Ignore timezone to simplify formatting python < 3.7
-                        # 3.7 has datetime.fromisoformat()
-                        dt, _sep, _tz = status.get("expires", "").partition("+")
-                        eol_date = datetime.datetime.strptime(
-                            dt, "%Y-%m-%dT%H:%M:%S"
-                        ).date()
-                except ValueError:
-                        print("Unable to determine UA contract expiry")
-                        eol_date = distro.eol
-        else:
-                eol_text = _("Basic Security Maintenance")
-                eol_date = distro.eol
-        self.label_esm_status.set_markup(eol_text)
-        esm_url = "https://ubuntu.com/esm"  # Non-EOL LTS generic ESM
-        today = datetime.datetime.now().date()
-        if today >= eol_date:
-                if esm_available:
-                        # EOL LTS uses release-specific ESM ubuntu.com/XX-YY
-                        distro_ver = distro.version.replace(' LTS', '')
-                        esm_url = "https://ubuntu.com/%s" % distro_ver.replace(".", "-")
-                eol_expiry_text = _("Ended %s - extend or upgrade now") % eol_date.strftime("%x")
-        elif today >= eol_date - datetime.timedelta(days=60):
-                eol_expiry_text = _("Ends %s - extend or upgrade soon") % eol_date.strftime("%x")
-        else:
-                eol_expiry_text = _("Active until %s") % eol_date.strftime("%x")
-        self.label_eol.set_label(eol_expiry_text)
-        self.label_esm_subscribe.set_markup(
-                "<a href=\"%s\">%s</a>" % (esm_url, _("Extend…"))
-        )
-        self.label_esm_subscribe.set_visible(
-                esm_available and not esm_enabled
-        )
-        eol_expiry_text = _("Ended %s") % eol_date.strftime("%x")
-
         # setup the server chooser
         cell = Gtk.CellRendererText()
         self.combobox_server.pack_start(cell, True)
@@ -1073,7 +1012,6 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
     def on_delete_event(self, widget, args):
         """Close the window if requested"""
         self.on_close_button(widget)
-        return False
 
     def on_close_button(self, widget):
         """Show a dialog that a reload of the channel information is required
@@ -1146,7 +1084,6 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
             self.transaction.connect("cancellable-changed", self.on_driver_changes_cancellable_changed)
             self.transaction.connect("finished", self.on_driver_changes_finish)
             self.transaction.connect("error", self.on_driver_changes_error)
-            self.transaction.set_debconf_frontend("gnome")
             self.transaction.run()
             self.button_driver_revert.set_sensitive(False)
             self.button_driver_apply.set_sensitive(False)
@@ -1263,7 +1200,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
                         lmp = self.apt_cache[linux_meta]
                         if not lmp.is_installed:
                             self.driver_changes.append(lmp)
-        except (AttributeError, KeyError):
+        except KeyError:
             pass
 
         if button.get_active():
@@ -1491,6 +1428,3 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
                                                % {'count': self.nonfree_drivers})
         else:
             self.label_driver_action.set_label(_("No proprietary drivers are in use."))
-
-    def init_ubuntu_pro(self):
-        self.ubuntu_pro_page = UbuntuProPage(self)
